# Pigment

**Pigment** is a set of Python utilities for colors.

```py
>>> red = Color(255, 0, 0)
>>> blue = Color(0, 0, 255)
>>> blend(red, blue).hsv
(300, 100, 50)
```

[![Downloads](https://pepy.tech/badge/pigment)](https://pepy.tech/project/pigment)
[![Supported Versions](https://img.shields.io/pypi/pyversions/pigment.svg)](https://pypi.org/project/pigment)
[![Testing](https://img.shields.io/github/workflow/status/bsoyka/pigment/Testing%20with%20pytest?label=tests)](https://github.com/bsoyka/pigment/actions?query=workflow%3A%22Testing+with+pytest%22)
[![License](https://img.shields.io/pypi/l/pigment)](https://github.com/bsoyka/pigment/blob/master/LICENSE)
[![Version](https://img.shields.io/pypi/v/pigment?label=latest)](https://pypi.org/project/pigment)

## Installation

Pigment is available on PyPI:

```console
$ python -m pip install pigment
```

Pigment officially supports Python 3.7+.

## API Reference

See [Read the Docs](https://pigment.readthedocs.io) for Pigment's documentation.
